@@ -21,10 +21,15 @@
 #ifndef MixDevice_h
 #define MixDevice_h
 
-// std::shared_ptr
+#include "config.h"
+
+#if defined(HAVE_STD_SHARED_PTR)
 #include <memory>
+using std::shared_ptr;
+#elif defined(HAVE_STD_TR1_SHARED_PTR)
 #include <tr1/memory>
-using namespace ::std::tr1;
+using std::tr1::shared_ptr;
+#endif
 
 //KMix
 class Mixer;
